"""Data models for AutoGLM-GUI."""

from AutoGLM_GUI.models.history import ConversationRecord, DeviceHistory
from AutoGLM_GUI.models.scheduled_task import ScheduledTask

__all__ = [
    "ConversationRecord",
    "DeviceHistory",
    "ScheduledTask",
]
